# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/eurolloyd/eurolloyds/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/eurolloyd/eurolloyds/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Eurolloyd\\Eurolloyds\\": "packages/eurolloyd/eurolloyds/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Eurolloyd\Eurolloyds\Providers\EurolloydsServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Eurolloyds'  => Eurolloyd\Eurolloyds\Facades\Eurolloyds::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Eurolloyd\\EurolloydsTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Eurolloyd\Eurolloyds\Providers\EurolloydsServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Eurolloyd\Eurolloyds\Providers\EurolloydsServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Eurolloyd\Eurolloyds\Providers\EurolloydsServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/eurolloyds/{modulename}

**User**

    http://path-to-route-folder/user/eurolloyds/{modulename}

**Public**

    http://path-to-route-folder/eurolloyds


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/eurolloyds/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/eurolloyds/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/eurolloyds/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/eurolloyds/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/eurolloyds/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/eurolloyds/{modulename}/{slug}
    METHOD: GET