<?php

namespace Eurolloyd\Eurolloyd\Providers;

use Illuminate\Support\ServiceProvider;

class EurolloydServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'eurolloyd');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'eurolloyd');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerEurolloyd();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerEurolloyd()
    {
        $this->app->bind('eurolloyd', function($app) {
            return new Eurolloyd($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Eurolloyd', 'Lavalite\Eurolloyd\Facades\Eurolloyd');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('eurolloyd.eurolloyd', function ($app) {
            return $this->app->make('Eurolloyd\Eurolloyd\Eurolloyd');
        });

                // Bind Object to repository
        $this->app->bind(
            'Eurolloyd\Eurolloyd\Interfaces\ObjectRepositoryInterface',
            \Eurolloyd\Eurolloyd\Repositories\Eloquent\ObjectRepository::class
        );

        $this->app->register(\Eurolloyd\Eurolloyd\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Eurolloyd\Eurolloyd\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and eurolloyd's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'eurolloyd.eurolloyd'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeEurolloyd::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['eurolloyd.eurolloyd'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('eurolloyd/eurolloyd.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/eurolloyd')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/eurolloyd')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
