<?php

namespace Eurolloyd\Eurolloyds\Providers;

use Illuminate\Support\ServiceProvider;

class EurolloydsServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'eurolloyds');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'eurolloyds');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerEurolloyds();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();
    }


    /**
     * Register the application bindings.
     *
     * @return void
     */
    protected function registerEurolloyds()
    {
        $this->app->bind('eurolloyds', function($app) {
            return new Eurolloyds($app);
        });
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->booting(function()
        {
            $loader = \Illuminate\Foundation\AliasLoader::getInstance();
            $loader->alias('Eurolloyds', 'Lavalite\Eurolloyds\Facades\Eurolloyds');
        });
    }

    /**
     * Register bindings for the provider.
     *
     * @return void
     */
    public function registerBindings() {
        // Bind facade
        $this->app->bind('eurolloyd.eurolloyds', function ($app) {
            return $this->app->make('Eurolloyd\Eurolloyds\Eurolloyds');
        });

                // Bind Object to repository
        $this->app->bind(
            'Eurolloyd\Eurolloyds\Interfaces\ObjectRepositoryInterface',
            \Eurolloyd\Eurolloyds\Repositories\Eloquent\ObjectRepository::class
        );

        $this->app->register(\Eurolloyd\Eurolloyds\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Eurolloyd\Eurolloyds\Providers\RouteServiceProvider::class);
            }

    /**
     * Merges user's and eurolloyds's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'eurolloyd.eurolloyds'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                Commands\MakeEurolloyds::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['eurolloyd.eurolloyds'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('eurolloyd/eurolloyds.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/eurolloyds')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/eurolloyds')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
